@@ -9,7 +9,7 @@
 #
 package CatalystX::Controller::ExtJS::Direct::API;
 BEGIN {
-  $CatalystX::Controller::ExtJS::Direct::API::VERSION = '2.1.3';
+  $CatalystX::Controller::ExtJS::Direct::API::VERSION = '2.1.4';
 }
 # ABSTRACT: API and router controller for Ext.Direct
 use Moose;
@@ -170,7 +170,7 @@ sub router {
                 my $msg;
                 if(@{ $c->error } && List::MoreUtils::all { ref $_ } @{ $c->error }) {
                     $msg = @{$c->error} == 1 ? $c->error->[0] : $c->error;
-                    $msg = $msg if(blessed $msg);
+                    $msg = "$msg" if(blessed $msg);
                 } elsif(scalar @{ $c->error }) {
                     $msg = join "\n", map { blessed $_ ? "$_" : $_ } @{ $c->error };
                 } else {
@@ -216,7 +216,7 @@ CatalystX::Controller::ExtJS::Direct::API - API and router controller for Ext.Di
 
 =head1 VERSION
 
-version 2.1.3
+version 2.1.4
 
 =head1 SYNOPSIS
 
