@@ -7,8 +7,7 @@
 #
 #   The (three-clause) BSD License
 #
-package
-  MyApp::View::JSON;
+package MyApp::View::JSON;
 
 use strict;
 use base 'Catalyst::View::JSON';
